from distutils.core import setup

setup (
	name		= 'time-sanitize',
	version		= '1.0.0',
	py_modules	= ['sanitize'],
	author		= 'tobypy16',
	author_email	= 'computerkid342@gmail.com',
	url		= 'linuxandbeyond.com',
	description	= 'A function that unifys different time formats (e.g, min:sec, min-sec, min.sec) to min.sec'
)



def sanitize(time_string):
     if '-' in time_string:
          splitter = '-'
     elif ':' in time_string:
          splitter = ':'
     else:
          return(time_string)
     (mins, secs) = time_string.split(splitter)
     return(mins + '.' + secs)
